{% extends "health_check/base.html" %}
{% load staticfiles %}

{% block content %}
  <div id="app"></div>

  <script id="api_url" type="text/plain">{% url "health_check:api_health_root" %}</script>
{% endblock %}

{% block js %}
  <script type="text/javascript" src="{% static "health_check/apps/health.js" %}"></script>
{% endblock js %}
