import keyMirror from "keymirror";

export default keyMirror({
  OK: null,
  FAIL: null,
  HEALTH_CHECK_UPDATE_ALL: null,
  HEALTH_UPDATE: null,
  HEALTH_UPDATE_ALL: null,
  STATS_UPDATE: null,
  STATS_UPDATE_ALL: null
});
