@import "bootstrap/scss/bootstrap";
@import "font-awesome/scss/font-awesome";
@import "colors";

body {
  background-color: $color3;
}

.card {
  background-color: $color1;
  color: $color5;
  border: 1px solid $color3;
  border-radius: 0;
  margin-bottom: 0;

  .card-title {
    text-transform: capitalize;
  }
}

.list-group-item {
  background-color: $color1;
  color: $color5;
  border-radius: 0;
  border: 1px solid $color3;

  &:hover, &:focus {
    text-decoration: none;
  }
}

.nested-list-group {
  > .list-group {
    padding: 0;
    overflow: hidden;

    .list-group {
      margin-bottom: 0;
      padding-left: 1em;
    }

    .list-group-item {
      border-radius: 0;

      > i {
        margin-right: 0.25em;
      }
    }
  }

  .nested-node {
    &:not(:last-child) .list-group > .list-group-item:last-child {
      margin-bottom: -1px;
    }

    &:last-child {
      > .list-group-item.collapsed {
        margin-bottom: 0;
      }

      > .list-group.collapsing {
        margin-top: -1px;
      }
    }
  }

  .nested-leaf {
    background-color: $color2;
    color: $color5;
  }
}
